//
// Copyright Inrupt Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
// INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
// PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

import type { EventEmitter } from "events";
import { jest } from "@jest/globals";

import type IIncomingRedirectHandler from "../IIncomingRedirectHandler";

const canHandle = jest.fn((_url: string) => Promise.resolve(true));

const handle = jest.fn((_url: string, _emitter: EventEmitter | undefined) =>
  Promise.resolve({
    sessionId: "global",
    isLoggedIn: true,
    webId: "https://pod.com/profile/card#me",
    fetch: jest.fn(globalThis.fetch),
  }),
);

export const mockCanHandleIncomingRedirect = canHandle;
export const mockHandleIncomingRedirect = handle;

export const mockIncomingRedirectHandler = (): IIncomingRedirectHandler => {
  return {
    canHandle,
    handle,
  };
};
